{% comment %}
NOTE: we override this file only to remove the _region_selection template
from the right navbar. When we have completely turned off multi region and
cleaned up the Keystone endpoints at each region, this override can go.
{% endcomment %}

{% load i18n %}

{% spaceless %}
<nav class="navbar navbar-default navbar-fixed-top">
    <div class="container-fluid">
        <!-- Brand and toggle get grouped for better mobile display -->
        <div class="navbar-header">
            {% include "header/_brand.html" %}

            <button id="sidebar-toggle"
                    type="button"
                    class="navbar-toggle pull-left">
                <span class="sr-only">{% trans "Toggle navigation" %}</span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
            </button>

            <button type="button"
                    class="navbar-toggle collapsed"
                    data-toggle="collapse"
                    data-target="#navbar-collapse">
                <span class="sr-only">{% trans "Toggle navigation" %}</span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
            </button>
        </div>

        <!-- Collect the nav links, forms, and other content for toggling -->
        <div class="collapse navbar-collapse"
             id="navbar-collapse">
            <ul class="nav navbar-nav">
                {% include "header/_context_selection.html" %}
            </ul>
            <ul class="nav navbar-nav navbar-right">
                {% if profiler_enabled %}
                {% include "developer/profiler/_mode_picker.html" %}
                {% endif %}
                {% include "header/_keystone_provider_selection.html" %}
                {% include "header/_user_menu.html" %}
            </ul>
            <ul class="nav navbar-nav navbar-right">
                <li>
                    <a href="https://wiki.debian.org/OpenStack/" target="_blank">Wiki</a>
                </li>
                <li>
                    <a href="https://docs.openstack.org/" target="_blank">OpenStack</a>
                </li>
            </ul>
        </div><!-- /.navbar-collapse -->
    </div><!-- /.container-fluid -->
</nav>
{% endspaceless %}